@@ -27,6 +27,11 @@ class WorkoutFileException(GenericException):
     pass
 
 
+class WorkoutNoFileException(GenericException):
+    def __init__(self) -> None:
+        super().__init__("error", "no workout file provided")
+
+
 class WorkoutGPXException(GenericException):
     pass
 
@@ -34,3 +39,7 @@ class WorkoutGPXException(GenericException):
 class WorkoutForbiddenException(GenericException):
     def __init__(self) -> None:
         super().__init__("error", "you do not have permissions")
+
+
+class WorkoutRefreshException(GenericException):
+    pass
