@@ -1,7 +1,10 @@
 from typing import TYPE_CHECKING
 
+from flask import current_app
+
 from ..exceptions import WorkoutExceedingValueException
 from ..models import PSQL_INTEGER_LIMIT, WORKOUT_VALUES_LIMIT
+from ..utils.gpx import get_file_extension
 
 if TYPE_CHECKING:
     from fittrackee.workouts.models import Workout
@@ -26,3 +29,20 @@ class CheckWorkoutMixin:
                 raise WorkoutExceedingValueException(
                     f"'{key}' exceeds max value ({max_value})"
                 )
+
+
+class WorkoutFileMixin:
+    @staticmethod
+    def _get_extension(filename: str) -> str:
+        return get_file_extension(filename)
+
+    @staticmethod
+    def _is_valid_workout_file_extension(extension: str) -> bool:
+        return (
+            extension in current_app.config["WORKOUT_ALLOWED_EXTENSIONS"]
+            and extension != "zip"
+        )
+
+    def _is_workout_file(self, filename: str) -> bool:
+        extension = self._get_extension(filename)
+        return self._is_valid_workout_file_extension(extension)
